纳甲六爻排盘项目
================


.. image:: https://img.shields.io/pypi/v/najia.svg
        :target: https://pypi.python.org/pypi/najia

.. image:: https://img.shields.io/travis/bopo/najia.svg
        :target: https://travis-ci.org/bopo/najia

.. image:: https://readthedocs.org/projects/najia/badge/?version=latest
        :target: https://najia.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/bopo/najia/shield.svg
     :target: https://pyup.io/repos/github/bopo/najia/
     :alt: Updates



Python Boilerplate contains all the boilerplate you need to create a Python package.


* Free software: MIT license
* Documentation: https://najia.readthedocs.io.


Features
--------

* 全部安易卦爻
* 函数独立编写
* 测试各个函数
* 重新命名函数

阳历，阴历（干支，旬空）

* 卦符: mark (001000)，自下而上
* 卦名: name
* 变爻: bian
* 卦宫: gong
* 六亲: qin6
* 六神: god6
* 世爻: shiy, ying
* 纳甲: naja
* 纳甲五行: dzwx
* 卦宫五行: gowx


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
